.. _ReferencePage:
  
=============
API Reference
=============

You can find automatically generated documentation for each module in the ``astLib`` package below.

astCalc
-------

.. automodule:: astLib.astCalc
   :members:


astCoords
---------

.. automodule:: astLib.astCoords
   :members:


astImages
---------

.. automodule:: astLib.astImages
   :members:


astPlots
--------

.. automodule:: astLib.astPlots
   :members:


astWCS
------

.. automodule:: astLib.astWCS
   :members:


astSED
------

.. automodule:: astLib.astSED
   :members:


